@@ -2,4 +2,4 @@
 # Author: zhangmingming
 # Email: 690126048@qq.com
 
-from .gvcode import VerificationCode
\ No newline at end of file
+from .gvcode import VFCode
\ No newline at end of file
